@@ -1,22 +1,23 @@
 /* Definitions for config file handling (not yet an object).
  *
- * Copyright 2008-2012 Adiscon GmbH.
+ * Copyright 2008 Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of rsyslog.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *       http://www.apache.org/licenses/LICENSE-2.0
- *       -or-
- *       see COPYING.ASL20 in the source distribution
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Rsyslog is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * Rsyslog is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Rsyslog.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * A copy of the GPL can be found in the file "COPYING" in this distribution.
  */
 #ifndef INCLUDED_CONF_H
 #define INCLUDED_CONF_H
@@ -27,6 +28,8 @@
  * somewhat strange (at least its name). -- rgerhards, 2007-08-01
  */
 enum eDirective { DIR_TEMPLATE = 0, DIR_OUTCHANNEL = 1, DIR_ALLOWEDSENDER = 2};
+extern ecslConfObjType currConfObj;
+extern int bConfStrictScoping;	/* force strict scoping during config processing? */
 
 /* interfaces */
 BEGINinterface(conf) /* name must also be changed in ENDinterface macro! */
@@ -37,8 +40,14 @@ BEGINinterface(conf) /* name must also be changed in ENDinterface macro! */
 	rsRetVal (*cfline)(uchar *line, rule_t **pfCurr);
 	rsRetVal (*processConfFile)(uchar *pConfFile);
 	rsRetVal (*GetNbrActActions)(int *);
+	/* version 4 -- 2010-07-23 rgerhards */
+	/* "just" added global variables
+	 * FYI: we reconsider repacking as a non-object, as only the core currently
+	 * accesses this module. The current object structure complicates things without
+	 * any real benefit.
+	 */
 ENDinterface(conf)
-#define confCURR_IF_VERSION 3 /* increment whenever you change the interface structure! */
+#define confCURR_IF_VERSION 4 /* increment whenever you change the interface structure! */
 /* in Version 3, entry point "ReInitConf()" was removed, as we do not longer need
  * to support restart-type HUP -- rgerhards, 2009-07-15
  */
